@@ -6,6 +6,7 @@
 
 from tornado.options import options, define
 
+
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.status_code import StatusCode
 
@@ -53,6 +54,11 @@ class InitConnectionPool:
                                                             fromlist="ElasticsearchPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "esapi":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.es.es_pool", fromlist="EsPool")
+                        # 执行用例
+                        pool = clazz(conn_info).create_pool()
                     elif conn_info.dialect == "redis":
                         # 获取包中用例的函数引用
                         clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
