@@ -8,10 +8,10 @@ import aiomysql
 
 
 class MysqlPool(BaseConnectionPool):
-
     """
     mysql 数据库链接创建类
     """
+
     async def create_pool(self):
         """
         创建mysql 异步连接池
@@ -20,7 +20,10 @@ class MysqlPool(BaseConnectionPool):
         if self.conn_info.async_enable:
             pool = await aiomysql.create_pool(host=self.conn_info.host, port=self.conn_info.port,
                                               user=self.conn_info.user,
-                                              password=self.conn_info.password, pool_recycle=3600*4,
+                                              password=self.conn_info.password,
+                                              pool_recycle=self.conn_info.params.get("pool_recycle",
+                                                                                     3600 * 4)
+                                              if self.conn_info.params else 3600 * 4,
                                               db=self.conn_info.db_name, autocommit=True,
                                               minsize=self.conn_info.min_size,
                                               maxsize=self.conn_info.max_size)
