@@ -33,8 +33,8 @@ class BaseHandler(RequestHandler):
         :param kwargs:
         """
         # 如果想要使用自定义响应，设置self.original为True
-        self.start_time = time.time()
-        self.end_time = time.time()
+        self.start_time = int(round(time.time() * 1000))
+        self.end_time = int(round(time.time() * 1000))
         self.original = False
         super().__init__(application, request, **kwargs)
 
@@ -96,8 +96,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.end_time = time.time()
-            self.set_header("ApiTime", self.end_time - self.start_time)
+            self.end_time = int(round(time.time() * 1000))
+            self.set_header("ApiTime", str(self.end_time - self.start_time))
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
@@ -185,8 +185,8 @@ class BaseHandler(RequestHandler):
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.end_time = time.time()
-            self.set_header("ApiTime", self.end_time - self.start_time)
+            self.end_time = int(round(time.time() * 1000))
+            self.set_header("ApiTime", str(self.end_time - self.start_time))
             if not self.original:
                 self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
